#
# Cookbook Name:: munki
# Recipe:: default
#
# Copyright 2014-2016 chris.gerke@gmail.com
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.
#

case node['platform_family']
when 'mac_os_x'

    directory "#{node['munki']['root']}/#{node['munki']['repo']}" do
        owner 'root'
        group 'admin'
        mode '0775'
        not_if { File.exists?("#{node['munki']['root']}/#{node['munki']['repo']}") }
    end

    directory "#{node['munki']['root']}/#{node['munki']['repo']}/catalogs" do
        owner 'root'
        group 'admin'
        mode '0775'
        not_if { File.exists?("#{node['munki']['root']}/#{node['munki']['repo']}/catalogs") }
    end

    directory "#{node['munki']['root']}/#{node['munki']['repo']}/manifests" do
        owner 'root'
        group 'admin'
        mode '0775'
        not_if { File.exists?("#{node['munki']['root']}/#{node['munki']['repo']}/manifests") }
    end

    directory "#{node['munki']['root']}/#{node['munki']['repo']}/pkgs" do
        owner 'root'
        group 'admin'
        mode '0775'
        not_if { File.exists?("#{node['munki']['root']}/#{node['munki']['repo']}/pkgs") }
    end

    directory "#{node['munki']['root']}/#{node['munki']['repo']}/pkgsinfo" do
        owner 'root'
        group 'admin'
        mode '0775'
        not_if { File.exists?("#{node['munki']['root']}/#{node['munki']['repo']}/pkgsinfo") }
    end

    # When using apache via osx server...
    execute "ln osx server" do
        command "/bin/ln -s #{node['munki']['root']}/#{node['munki']['repo']} /Library/Server/Web/Data/Sites/Default/#{node['munki']['repo']}"
        only_if { File.exists?('/Library/Server/Web/Data/Sites/Default') }
        not_if "/usr/bin/readlink /Library/Server/Web/Data/Sites/Default/#{node['munki']['repo']} | /usr/bin/grep #{node['munki']['root']}/#{node['munki']['repo']}"
    end

    # ...or when using apache via osx workstation
    execute "ln osx workstation" do
        command "/bin/ln -s #{node['munki']['root']}/#{node['munki']['repo']} /Library/WebServer/Documents/#{node['munki']['repo']}"
        only_if { not File.exists?('/Library/Server/Web/Data/Sites/Default') }
        not_if "/usr/bin/readlink /Library/WebServer/Documents/#{node['munki']['repo']} | /usr/bin/grep #{node['munki']['root']}/#{node['munki']['repo']}"
    end

    bash 'apache osx workstation autostart' do
        code <<-EOH
            /bin/launchctl load -w /System/Library/LaunchDaemons/org.apache.httpd.plist
            EOH
        only_if { not File.exists?('/Library/Server/Web/Data/Sites/Default') }
        not_if "/bin/launchctl list | /usr/bin/grep org.apache.httpd"
    end

    bash 'apache osx workstation http.conf' do
        code <<-EOH
            datetostring=$(date +"%Y%m%d%H%M%S")
            /bin/cp -f /etc/apache2/httpd.conf /etc/apache2/httpd.conf.${datetostring}
            EOH
        only_if { not File.exists?('/Library/Server/Web/Data/Sites/Default') }
        not_if "/bin/cat /etc/apache2/httpd.conf | /usr/bin/grep 'Options Indexes FollowSymLinks Multiviews'"
    end

    template '/etc/apache2/httpd.conf' do
        source 'httpd.conf.erb'
        owner 'root'
        group 'wheel'
        mode '0644'
        notifies :run, 'bash[apache osx workstation restart]', :immediately
    end

    bash 'apache osx workstation restart' do
        code <<-EOH
            /usr/sbin/apachectl restart
            EOH
        action :nothing
    end
    
    bash 'munki github latest official release' do
        code <<-EOH
            version=$(/usr/bin/curl https://github.com/munki/munki/releases | /usr/bin/grep 'Official Release' | /usr/bin/cut -d'>' -f2 | /usr/bin/awk '{print $2}' | /usr/bin/head -1)
            pkg=$(/usr/bin/curl https://github.com/munki/munki/releases | /usr/bin/grep download | /usr/bin/grep ${version} | /usr/bin/cut -d'/' -f7 | /usr/bin/cut -d'"' -f1)
            pushd /tmp
            /usr/bin/curl -#L -O "https://github.com/munki/munki/releases/download/v${version}/${pkg}"
            /usr/sbin/installer -verboseR -pkg *${version}* -target /
            EOH
        not_if { ::File.exists?('/usr/local/munki') }
    end

    template "#{node['munki']['user']}/com.googlecode.munki.munkiimport.plist" do
        source 'com.googlecode.munki.munkiimport.plist.erb'
        owner 'root'
        group 'admin'
        mode '0775'
    end

end